Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type GitHub ¶
type GitHub interface {
// RepositoryID finds a respoitory metadata based on owner and name of the
// repository.
RepositoryData() (Repository, error)
// MapUsers takes all login strings used in issues and searches GitHub for
// IDs for the logins. It returns a map of logins used as keys, and IDs used
// as values. If ID is not found, the value is empty string.
MapUsers([]string) (map[string]string, error)
// Creates issues for a repository. It assumes that the repository has no
// issues.
WriteIssues([]Issue, Repository, map[string]string) error
}
GitHub interface contains methods that are needed for creating issues for a repository.
type Issue ¶
type Issue struct {
Author Actor `json:"author"`
ID string `json:"id,omitempty"`
Number int `json:"number"`
Title string `json:"title"`
Body string `json:"body,omitempty"`
URL string `json:"url"`
Closed bool `json:"closed"`
ClosedAt *time.Time `json:"closedAt"`
CreatedAt time.Time `json:"createdAt"`
Assignees `json:"assignees,omitempty"`
Comments `json:"comments,omitempty"`
Labels `json:"labels,omitempty"`
}
type Repository ¶
Click to show internal directories.
Click to hide internal directories.